// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package qm

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	svr "LAPP_LF_MOM_BACKEND/services/qm"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块qm路由分组
	grmi.RegisterRouteMapping("/qm", func(party router.Party) {

		// ArtView的路由组
		artview := party.Party("/artview")
		// ArtView的服务实例
		var serviceOfArtView = svr.NewArtViewService()
		// ArtView插入一条
		// RegisterInsertOneArtView(artview, "/insertone", serviceOfArtView.InsertOne)
		// ArtView插入多条
		// RegisterInsertArtView(artview, "/insert", serviceOfArtView.Insert)
		// ArtView删除一条
		// RegisterDeleteOneArtView(artview, "/deleteone", serviceOfArtView.DeleteOne)
		// ArtView删除多条
		// RegisterDeleteArtView(artview, "/delete", serviceOfArtView.Delete)
		// ArtView查询多条
		RegisterSelectArtView(artview, "/query", serviceOfArtView.Select)
		// ArtView查询一条
		RegisterSelectOneArtView(artview, "/get", serviceOfArtView.SelectOne)
		// ArtView修改一条
		// RegisterUpdateOneArtView(artview, "/updateone", serviceOfArtView.UpdateOne)
		// ArtView修改多条
		RegisterUpdateArtView(artview, "/update", serviceOfArtView.Update)

		// View的路由组
		view := party.Party("/view")
		// View的服务实例
		var serviceOfView = svr.NewViewService()
		// View插入一条
		RegisterInsertOneView(view, "/insertone", serviceOfView.InsertOne)
		// View插入多条
		// RegisterInsertView(view, "/insert", serviceOfView.Insert)
		// View删除一条
		RegisterDeleteOneView(view, "/deleteone", serviceOfView.DeleteOne)
		// View删除多条
		// RegisterDeleteView(view, "/delete", serviceOfView.Delete)
		// View查询多条
		RegisterSelectView(view, "/query", serviceOfView.Select)
		// View查询一条
		RegisterSelectOneView(view, "/get", serviceOfView.SelectOne)
		// View修改一条
		RegisterUpdateOneView(view, "/updateone", serviceOfView.UpdateOne)
		// View修改多条
		// RegisterUpdateView(view, "/update", serviceOfView.Update)

		// DefectRecord的路由组
		defectrecord := party.Party("/defectrecord")
		// DefectRecord的服务实例
		var serviceOfDefectRecord = svr.NewDefectRecordService()
		// DefectRecord插入一条
		// RegisterInsertOneDefectRecord(defectrecord, "/insertone", serviceOfDefectRecord.InsertOne)
		// DefectRecord插入多条
		RegisterInsertDefectRecord(defectrecord, "/insert", serviceOfDefectRecord.Insert)
		// DefectRecord删除一条
		// RegisterDeleteOneDefectRecord(defectrecord, "/deleteone", serviceOfDefectRecord.DeleteOne)
		// DefectRecord删除多条
		// RegisterDeleteDefectRecord(defectrecord, "/delete", serviceOfDefectRecord.Delete)
		// DefectRecord查询多条
		RegisterSelectDefectRecord(defectrecord, "/query", serviceOfDefectRecord.Select)
		// DefectRecord查询一条
		RegisterSelectOneDefectRecord(defectrecord, "/get", serviceOfDefectRecord.SelectOne)
		// DefectRecord修改一条
		// RegisterUpdateOneDefectRecord(defectrecord, "/updateone", serviceOfDefectRecord.UpdateOne)
		// DefectRecord修改多条
		// RegisterUpdateDefectRecord(defectrecord, "/update", serviceOfDefectRecord.Update)
		// 返工
		RegisterIDOfDefectRecord(defectrecord, "POST", "/rework"+"/{recNr:int}", serviceOfDefectRecord.Rework)

		// ViewValst的路由组
		viewvalst := party.Party("/viewvalst")
		// ViewValst的服务实例
		var serviceOfViewValst = svr.NewViewValstService()
		// ViewValst插入一条
		// RegisterInsertOneViewValst(viewvalst, "/insertone", serviceOfViewValst.InsertOne)
		// ViewValst插入多条
		// RegisterInsertViewValst(viewvalst, "/insert", serviceOfViewValst.Insert)
		// ViewValst删除一条
		// RegisterDeleteOneViewValst(viewvalst, "/deleteone", serviceOfViewValst.DeleteOne)
		// ViewValst删除多条
		// RegisterDeleteViewValst(viewvalst, "/delete", serviceOfViewValst.Delete)
		// ViewValst查询多条
		RegisterSelectViewValst(viewvalst, "/query", serviceOfViewValst.Select)
		// ViewValst查询一条
		RegisterSelectOneViewValst(viewvalst, "/get", serviceOfViewValst.SelectOne)
		// ViewValst修改一条
		// RegisterUpdateOneViewValst(viewvalst, "/updateone", serviceOfViewValst.UpdateOne)
		// ViewValst修改多条
		// RegisterUpdateViewValst(viewvalst, "/update", serviceOfViewValst.Update)

		// ViewDefectGrplst的路由组
		viewdefectgrplst := party.Party("/viewdefectgrplst")
		// ViewDefectGrplst的服务实例
		var serviceOfViewDefectGrplst = svr.NewViewDefectGrplstService()
		// ViewDefectGrplst插入一条
		// RegisterInsertOneViewDefectGrplst(viewdefectgrplst, "/insertone", serviceOfViewDefectGrplst.InsertOne)
		// ViewDefectGrplst插入多条
		// RegisterInsertViewDefectGrplst(viewdefectgrplst, "/insert", serviceOfViewDefectGrplst.Insert)
		// ViewDefectGrplst删除一条
		// RegisterDeleteOneViewDefectGrplst(viewdefectgrplst, "/deleteone", serviceOfViewDefectGrplst.DeleteOne)
		// ViewDefectGrplst删除多条
		// RegisterDeleteViewDefectGrplst(viewdefectgrplst, "/delete", serviceOfViewDefectGrplst.Delete)
		// ViewDefectGrplst查询多条
		RegisterSelectViewDefectGrplst(viewdefectgrplst, "/query", serviceOfViewDefectGrplst.Select)
		// ViewDefectGrplst查询一条
		RegisterSelectOneViewDefectGrplst(viewdefectgrplst, "/get", serviceOfViewDefectGrplst.SelectOne)
		// ViewDefectGrplst修改一条
		// RegisterUpdateOneViewDefectGrplst(viewdefectgrplst, "/updateone", serviceOfViewDefectGrplst.UpdateOne)
		// ViewDefectGrplst修改多条
		// RegisterUpdateViewDefectGrplst(viewdefectgrplst, "/update", serviceOfViewDefectGrplst.Update)

		// ViewDefectlst的路由组
		viewdefectlst := party.Party("/viewdefectlst")
		// ViewDefectlst的服务实例
		var serviceOfViewDefectlst = svr.NewViewDefectlstService()
		// ViewDefectlst插入一条
		// RegisterInsertOneViewDefectlst(viewdefectlst, "/insertone", serviceOfViewDefectlst.InsertOne)
		// ViewDefectlst插入多条
		// RegisterInsertViewDefectlst(viewdefectlst, "/insert", serviceOfViewDefectlst.Insert)
		// ViewDefectlst删除一条
		// RegisterDeleteOneViewDefectlst(viewdefectlst, "/deleteone", serviceOfViewDefectlst.DeleteOne)
		// ViewDefectlst删除多条
		// RegisterDeleteViewDefectlst(viewdefectlst, "/delete", serviceOfViewDefectlst.Delete)
		// ViewDefectlst查询多条
		RegisterSelectViewDefectlst(viewdefectlst, "/query", serviceOfViewDefectlst.Select)
		// ViewDefectlst查询一条
		RegisterSelectOneViewDefectlst(viewdefectlst, "/get", serviceOfViewDefectlst.SelectOne)
		// ViewDefectlst修改一条
		// RegisterUpdateOneViewDefectlst(viewdefectlst, "/updateone", serviceOfViewDefectlst.UpdateOne)
		// ViewDefectlst修改多条
		// RegisterUpdateViewDefectlst(viewdefectlst, "/update", serviceOfViewDefectlst.Update)

		// DefectGrp的路由组
		defectgrp := party.Party("/defectgrp")
		// DefectGrp的服务实例
		var serviceOfDefectGrp = svr.NewDefectGrpService()
		// DefectGrp插入一条
		RegisterInsertOneDefectGrp(defectgrp, "/insertone", serviceOfDefectGrp.InsertOne)
		// DefectGrp插入多条
		// RegisterInsertDefectGrp(defectgrp, "/insert", serviceOfDefectGrp.Insert)
		// DefectGrp删除一条
		RegisterDeleteOneDefectGrp(defectgrp, "/deleteone", serviceOfDefectGrp.DeleteOne)
		// DefectGrp删除多条
		// RegisterDeleteDefectGrp(defectgrp, "/delete", serviceOfDefectGrp.Delete)
		// DefectGrp查询多条
		RegisterSelectDefectGrp(defectgrp, "/query", serviceOfDefectGrp.Select)
		// DefectGrp查询一条
		RegisterSelectOneDefectGrp(defectgrp, "/get", serviceOfDefectGrp.SelectOne)
		// DefectGrp修改一条
		RegisterUpdateOneDefectGrp(defectgrp, "/updateone", serviceOfDefectGrp.UpdateOne)
		// DefectGrp修改多条
		// RegisterUpdateDefectGrp(defectgrp, "/update", serviceOfDefectGrp.Update)

		// DefectGrpReasonLst的路由组
		defectgrpreasonlst := party.Party("/defectgrpreasonlst")
		// DefectGrpReasonLst的服务实例
		var serviceOfDefectGrpReasonLst = svr.NewDefectGrpReasonLstService()
		// DefectGrpReasonLst插入一条
		// RegisterInsertOneDefectGrpReasonLst(defectgrpreasonlst, "/insertone", serviceOfDefectGrpReasonLst.InsertOne)
		// DefectGrpReasonLst插入多条
		// RegisterInsertDefectGrpReasonLst(defectgrpreasonlst, "/insert", serviceOfDefectGrpReasonLst.Insert)
		// DefectGrpReasonLst删除一条
		// RegisterDeleteOneDefectGrpReasonLst(defectgrpreasonlst, "/deleteone", serviceOfDefectGrpReasonLst.DeleteOne)
		// DefectGrpReasonLst删除多条
		// RegisterDeleteDefectGrpReasonLst(defectgrpreasonlst, "/delete", serviceOfDefectGrpReasonLst.Delete)
		// DefectGrpReasonLst查询多条
		RegisterSelectDefectGrpReasonLst(defectgrpreasonlst, "/query", serviceOfDefectGrpReasonLst.Select)
		// DefectGrpReasonLst查询一条
		RegisterSelectOneDefectGrpReasonLst(defectgrpreasonlst, "/get", serviceOfDefectGrpReasonLst.SelectOne)
		// DefectGrpReasonLst修改一条
		// RegisterUpdateOneDefectGrpReasonLst(defectgrpreasonlst, "/updateone", serviceOfDefectGrpReasonLst.UpdateOne)
		// DefectGrpReasonLst修改多条
		// RegisterUpdateDefectGrpReasonLst(defectgrpreasonlst, "/update", serviceOfDefectGrpReasonLst.Update)

		// DefectReason的路由组
		defectreason := party.Party("/defectreason")
		// DefectReason的服务实例
		var serviceOfDefectReason = svr.NewDefectReasonService()
		// DefectReason插入一条
		// RegisterInsertOneDefectReason(defectreason, "/insertone", serviceOfDefectReason.InsertOne)
		// DefectReason插入多条
		// RegisterInsertDefectReason(defectreason, "/insert", serviceOfDefectReason.Insert)
		// DefectReason删除一条
		// RegisterDeleteOneDefectReason(defectreason, "/deleteone", serviceOfDefectReason.DeleteOne)
		// DefectReason删除多条
		// RegisterDeleteDefectReason(defectreason, "/delete", serviceOfDefectReason.Delete)
		// DefectReason查询多条
		RegisterSelectDefectReason(defectreason, "/query", serviceOfDefectReason.Select)
		// DefectReason查询一条
		RegisterSelectOneDefectReason(defectreason, "/get", serviceOfDefectReason.SelectOne)
		// DefectReason修改一条
		// RegisterUpdateOneDefectReason(defectreason, "/updateone", serviceOfDefectReason.UpdateOne)
		// DefectReason修改多条
		// RegisterUpdateDefectReason(defectreason, "/update", serviceOfDefectReason.Update)

		// SerialOrderRuting的路由组
		serialorderruting := party.Party("/serialorderruting")
		// SerialOrderRuting的服务实例
		var serviceOfSerialOrderRuting = svr.NewSerialOrderRutingService()
		// SerialOrderRuting插入一条
		// RegisterInsertOneSerialOrderRuting(serialorderruting, "/insertone", serviceOfSerialOrderRuting.InsertOne)
		// SerialOrderRuting插入多条
		// RegisterInsertSerialOrderRuting(serialorderruting, "/insert", serviceOfSerialOrderRuting.Insert)
		// SerialOrderRuting删除一条
		// RegisterDeleteOneSerialOrderRuting(serialorderruting, "/deleteone", serviceOfSerialOrderRuting.DeleteOne)
		// SerialOrderRuting删除多条
		// RegisterDeleteSerialOrderRuting(serialorderruting, "/delete", serviceOfSerialOrderRuting.Delete)
		// SerialOrderRuting查询多条
		RegisterSelectSerialOrderRuting(serialorderruting, "/query", serviceOfSerialOrderRuting.Select)
		// SerialOrderRuting查询一条
		RegisterSelectOneSerialOrderRuting(serialorderruting, "/get", serviceOfSerialOrderRuting.SelectOne)
		// SerialOrderRuting修改一条
		// RegisterUpdateOneSerialOrderRuting(serialorderruting, "/updateone", serviceOfSerialOrderRuting.UpdateOne)
		// SerialOrderRuting修改多条
		// RegisterUpdateSerialOrderRuting(serialorderruting, "/update", serviceOfSerialOrderRuting.Update)

		// ReclinerReclst的路由组
		reclinerreclst := party.Party("/reclinerreclst")
		// ReclinerReclst的服务实例
		var serviceOfReclinerReclst = svr.NewReclinerReclstService()
		// ReclinerReclst插入一条
		RegisterInsertOneReclinerReclst(reclinerreclst, "/insertone", serviceOfReclinerReclst.InsertOne)
		//添加打印消息
		RegisterAddPrinterInfo(reclinerreclst, "/addprinterinfo", serviceOfReclinerReclst.AddPrinterInfo)
		// ReclinerReclst插入多条
		// RegisterInsertReclinerReclst(reclinerreclst, "/insert", serviceOfReclinerReclst.Insert)
		// ReclinerReclst删除一条
		// RegisterDeleteOneReclinerReclst(reclinerreclst, "/deleteone", serviceOfReclinerReclst.DeleteOne)
		// ReclinerReclst删除多条
		// RegisterDeleteReclinerReclst(reclinerreclst, "/delete", serviceOfReclinerReclst.Delete)
		// ReclinerReclst查询多条
		RegisterSelectReclinerReclst(reclinerreclst, "/query", serviceOfReclinerReclst.Select)
		// ReclinerReclst查询一条
		RegisterSelectOneReclinerReclst(reclinerreclst, "/get", serviceOfReclinerReclst.SelectOne)
		// ReclinerReclst修改一条
		// RegisterUpdateOneReclinerReclst(reclinerreclst, "/updateone", serviceOfReclinerReclst.UpdateOne)
		// ReclinerReclst修改多条
		// RegisterUpdateReclinerReclst(reclinerreclst, "/update", serviceOfReclinerReclst.Update)
	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
